ActorBase
=========

.. currentmodule:: atqo

.. autoclass:: ActorBase
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ActorBase.consume
      ~ActorBase.stop

   .. rubric:: Methods Documentation

   .. automethod:: consume
   .. automethod:: stop
